@@ -5,12 +5,14 @@
 #' @description Plots difficulty and discrimination for items ordered by difficulty.
 #'
 #' @param data numeric: binary data matrix or data frame. See \strong{Details}.
+#' @param item.names character: the names of items.
 #'
-#' @usage DDplot(data)
+#' @usage DDplot(data, item.names)
 #'
 #' @details
 #' The \code{data} is a matrix or data frame whose rows represents examinee answers
-#' ("1" correct, "0" incorrect) and columns correspond to the items.
+#' ("1" correct, "0" incorrect) and columns correspond to the items. The \code{item.names}
+#' argument stands for names of items. If not specified, the names of dataset columns are used.
 #'
 #' @author
 #' Adela Drabinova \cr
@@ -55,12 +57,12 @@
 #' @importFrom reshape2 dcast melt
 #' @importFrom rmarkdown render
 #' @importFrom shinyjs show hide useShinyjs
-#' @importFrom stats aggregate coef deriv deriv3 fitted glm median nls quantile relevel sd vcov xtabs
+#' @importFrom stats aggregate coef complete.cases deriv deriv3 fitted glm median nls quantile relevel sd vcov xtabs
 #' @importFrom stringr str_sub
 #' @importFrom utils data read.csv
 
 
-DDplot <- function(data){
+DDplot <- function(data, item.names){
   if (is.matrix(data) | is.data.frame(data)) {
     if (!all(apply(data, 2, function(i) {
       length(levels(as.factor(i))) == 2
@@ -73,14 +75,18 @@ DDplot <- function(data){
          call. = FALSE)
   }
 
+  if(missing(item.names)){
+    item.names <- colnames(data)
+  }
+
   # difficulty and discrimination
   difc <- psychometric::item.exam(data, discr = T)[, "Difficulty"]
   disc <- psychometric::item.exam(data, discr = T)[, "Discrimination"]
   value <- c(rbind(difc, disc)[, order(difc)])
   parameter <- rep(c("Difficulty", "Discrimination"), ncol(data))
   # ordered by difficulty
-  item <- factor(rep(order(difc), rep(2, ncol(data))),
-                 levels = factor(order(difc)))
+  item <- factor(rep(item.names[order(difc)], each = 2),
+                    levels = item.names[order(difc)])
   df <- data.frame(item, parameter, value)
 
   # plot
@@ -88,12 +94,12 @@ DDplot <- function(data){
   ggplot(df,
          aes_string(x = "item", y = "value", fill = "parameter", color = "parameter")) +
     stat_summary(fun.y = mean,
-                 position = position_dodge(),
+                 position = "dodge",
                  geom = "bar",
                  alpha = 0.7,
                  width = 0.8) +
     geom_hline(yintercept = 0.2) +
-    xlab("Item Number (Ordered by Difficulty)") +
+    xlab("Item (ordered by difficulty)") +
     ylab("Difficulty/Discrimination") +
     scale_y_continuous(expand = c(0, 0), limits = c(0, 1)) +
     scale_fill_manual(breaks = parameter,
@@ -103,7 +109,7 @@ DDplot <- function(data){
     theme_bw() +
     theme(axis.line  = element_line(colour = "black"),
           text = element_text(size = 14),
-          axis.text.x = element_text(angle = 90, hjust = 1),
+          axis.text.x = element_text(angle = 90, vjust = 0.5),
           panel.grid.major = element_blank(),
           panel.grid.minor = element_blank(),
           panel.background = element_blank(),
