@@ -8,10 +8,11 @@
 #' @param test character: type of statistic to be shown. See \strong{Details}.
 #' @param item either character ("all"), or numeric vector, or single number
 #' corresponding to column indicators. See \strong{Details}.
+#' @param item.name character: the name of item.
 #' @param same.scale logical: are the item \code{parameters} on the same scale?
 #' (default is "FALSE"). See \strong{Details}.
 #'
-#' @usage plotDIFirt(parameters, test = "Lord", item = "all", same.scale = F)
+#' @usage plotDIFirt(parameters, test = "Lord", item = "all", item.name, same.scale = F)
 #'
 #' @details
 #' This function plots characteristic curve of DIF IRT model.
@@ -69,7 +70,8 @@
 #' @export
 
 
-plotDIFirt <- function(parameters, test = "Lord", item = "all", same.scale = F){
+plotDIFirt <- function(parameters, test = "Lord", item = "all", item.name, same.scale = F){
+
 
   if (!(test %in% c("Lord", "Raju"))){
     stop("'test' must be either 'Lord' or 'Raju'",
@@ -108,6 +110,13 @@ plotDIFirt <- function(parameters, test = "Lord", item = "all", same.scale = F){
     items <- item
   }
 
+  if (missing(item.name)){
+    item.names <- paste("Item", 1:m)
+  } else {
+    item.names <- rep(NA, m)
+    item.names[items] <- item.name
+  }
+
   mR <- parameters[1:m, ]
   mF <- parameters[(m+1):(2*m), ]
 
@@ -166,7 +175,7 @@ plotDIFirt <- function(parameters, test = "Lord", item = "all", same.scale = F){
                                       values = linetype) +
                 ### theme
                 xlab("Ability") +
-                ylab("Probability of Correct Answer") +
+                ylab("Probability of correct answer") +
                 scale_y_continuous(expand = c(0, 0), limits = c(0, 1))  +
                 theme_bw() +
                 theme(text = element_text(size = 14),
@@ -185,7 +194,7 @@ plotDIFirt <- function(parameters, test = "Lord", item = "all", same.scale = F){
                       legend.text.align = 0,
                       legend.title.align = 0,
                       legend.key = element_rect(colour = "white")) +
-                ggtitle(paste("Item", item))
+                ggtitle(item.names[i])
 
 
   if (test == "Raju"){
